==> h2o-java-rest-bindings-3.8.2.4-sources.jar: water/bindings/pojos/FramesV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class FramesV3 extends FramesBase {
    /* INHERITED: Name of Frame of interest 
    public FrameKeyV3 frame_id = null;
     */

    /* INHERITED: Name of column of interest 
    public String column = "";
     */

    /* INHERITED: Row offset to return 
    public long row_offset = 0L;
     */

    /* INHERITED: Number of rows to return 
    public int row_count = 0;
     */

    /* INHERITED: Column offset to return 
    public int column_offset = 0;
     */

    /* INHERITED: Number of columns to return 
    public int column_count = 0;
     */

    /* INHERITED: Find and return compatible models? 
    public boolean find_compatible_models = false;
     */

    /* INHERITED: File output path 
    public String path = "";
     */

    /* INHERITED: Overwrite existing file 
    public boolean force = false;
     */

    /* INHERITED: Job for export file 
    public JobV3 job = null;
     */

    /* INHERITED: Frames 
    public FrameBase[] frames = null;
     */

    /* INHERITED: Compatible models 
    public ModelSynopsisV3[] compatible_models = null;
     */

    /* INHERITED: Domains 
    public String[][] domain = null;
     */

    /* INHERITED: Comma-separated list of JSON field paths to exclude from the result, used like: "/3/Frames?_exclude_fields=frames/frame_id/URL,__meta" 
    public String _exclude_fields = "";
     */

    public FramesV3() {
        frame_id = null;
        column = "";
        row_offset = 0L;
        row_count = 0;
        column_offset = 0;
        column_count = 0;
        find_compatible_models = false;
        path = "";
        force = false;
        job = null;
        frames = null;
        compatible_models = null;
        domain = null;
        _exclude_fields = "";
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.11-sources.jar: water/bindings/pojos/FramesV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
public class FramesV3 extends FramesBase {
    /* INHERITED: Name of Frame of interest 
     * public FrameKeyV3 frame_id;
     */

    /* INHERITED: Name of column of interest 
     * public String column;
     */

    /* INHERITED: Row offset to return 
     * public long row_offset;
     */

    /* INHERITED: Number of rows to return 
     * public int row_count;
     */

    /* INHERITED: Column offset to return 
     * public int column_offset;
     */

    /* INHERITED: Number of columns to return 
     * public int column_count;
     */

    /* INHERITED: Find and return compatible models? 
     * public boolean find_compatible_models;
     */

    /* INHERITED: File output path 
     * public String path;
     */

    /* INHERITED: Overwrite existing file 
     * public boolean force;
     */

    /* INHERITED: Job for export file 
     * public JobV3 job;
     */

    /* INHERITED: Frames 
     * public FrameBase[] frames;
     */

    /* INHERITED: Compatible models 
     * public ModelSynopsisV3[] compatible_models;
     */

    /* INHERITED: Domains 
     * public String[][] domain;
     */

    /* INHERITED: Comma-separated list of JSON field paths to exclude from the result, used like: "/3/Frames?_exclude_fields=frames/frame_id/URL,__meta" 
     * public String _exclude_fields;
     */

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
